@@ -1,43 +1,77 @@
 # system configuration generated and used by the sysconfig module
-build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
+build_time_vars = {'ABIFLAGS': 'm',
+ 'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ATHEOS_THREADS': 0,
- 'BASECFLAGS': '-fno-strict-aliasing',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
+ 'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
- 'BEOS_THREADS': 0,
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python2.7',
- 'BLDLIBRARY': 'libpython2.7.dll.a',
- 'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base -L.',
+ 'BINLIBDEST': '/usr/lib/python3.5',
+ 'BLDLIBRARY': '-L. -lpython3.5m',
+ 'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
  'BUILDEXE': '.exe',
  'BUILDPYTHON': 'python.exe',
+ 'BUILD_GNU_TYPE': 'x86_64-pc-cygwin',
+ 'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '',
- 'CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-4.x86_64/build=/usr/src/debug/python2-2.7.18-4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18=/usr/src/debug/python2-2.7.18-4 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
+           '-Wstrict-prototypes -ggdb -O2 -pipe -Wall -Werror=format-security '
+           '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+           '--param=ssp-buffer-size=4 '
+           '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
+           '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1',
  'CFLAGSFORSHARED': '',
- 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18' '--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' '--sysconfdir=/etc' '--docdir=/usr/share/doc/python2' '--htmldir=/usr/share/doc/python2/html' '-C' '--enable-shared' '--enable-ipv6' '--with-dbmliborder=gdbm' '--with-libc=' '--with-libm=' '--with-system-ffi' '--with-system-expat' 'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' 'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-4.x86_64/build=/usr/src/debug/python2-2.7.18-4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18=/usr/src/debug/python2-2.7.18-4' 'LDFLAGS= -L.' 'LIBS=' 'CPPFLAGS='",
+ 'CFLAGS_ALIASING': '',
+ 'CFLAGS_NODIST': '',
+ 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
+                'Makefile.pre.in',
+ 'CONFIGURE_CFLAGS': '-ggdb -O2 -pipe -Wall -Werror=format-security '
+                     '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+                     '--param=ssp-buffer-size=4 '
+                     '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
+                     '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1',
+ 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'CONFIGURE_CPPFLAGS': '',
+ 'CONFIGURE_LDFLAGS': '',
+ 'CONFIG_ARGS': "'--srcdir=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6' "
+                "'--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' "
+                "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python35' "
+                "'--htmldir=/usr/share/doc/python35/html' '-C' "
+                "'--enable-shared' '--enable-ipv6' '--with-dbmliborder=gdbm' "
+                "'--with-libc=' '--with-libm=' '--with-system-expat' "
+                "'--with-system-ffi' '--without-ensurepip' "
+                "'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' "
+                "'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security "
+                '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+                '--param=ssp-buffer-size=4 '
+                '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
+                "-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1' "
+                "'LDFLAGS=' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python2.7',
- 'COREPYTHONPATH': ':plat-cygwin:lib-tk:lib-old',
- 'COVERAGE_INFO': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/build/coverage.info',
- 'COVERAGE_REPORT': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/build/lcov-report',
- 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
- 'CPPFLAGS': '-I. -IInclude -I/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18/Include',
+ 'CONFINCLUDEPY': '/usr/include/python3.5m',
+ 'COREPYTHONPATH': ':plat-cygwin',
+ 'COVERAGE_INFO': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/build/coverage.info',
+ 'COVERAGE_REPORT': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/build/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
+                            'report"',
+ 'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
+             '-I/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Include',
  'CXX': 'g++',
- 'C_THREADS': 0,
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python2.7 /usr/lib/python2.7/lib-dynload',
- 'DESTLIB': '/usr/lib/python2.7',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.5 /usr/lib/python3.5/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.5',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python2.7/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.5/lib-dynload',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Demo Ext-dummy',
- 'DISTDIRS': 'Include Lib Misc Demo Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+         'Makefile.pre.in Include Lib Misc Ext-dummy',
+ 'DISTDIRS': 'Include Lib Misc Ext-dummy',
+ 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+              'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
- 'DLLLIBRARY': 'libpython2.7.dll',
+ 'DLLLIBRARY': 'libpython3.5m.dll',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
@@ -47,9 +81,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'EXE': '.exe',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
- 'EXTRAPLATDIR': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
+ 'EXT_SUFFIX': '.cpython-35m-x86_64-cygwin.dll',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -57,20 +91,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
- 'GLHACK': '-Dclear=__GLclear',
  'GNULD': 'yes',
+ 'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 1,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 1,
  'HAVE_ATANH': 1,
- 'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
+ 'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 1,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
@@ -78,30 +113,24 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_BROKEN_PTHREAD_SIGMASK': 1,
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
+ 'HAVE_BUILTIN_ATOMIC': 1,
  'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 0,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
+ 'HAVE_CLOCK_GETRES': 1,
+ 'HAVE_CLOCK_GETTIME': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
- 'HAVE_CRYPT_H': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
- 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
- 'HAVE_CURSES_HAS_KEY': 1,
- 'HAVE_CURSES_IMMEDOK': 1,
- 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
- 'HAVE_CURSES_SYNCOK': 1,
- 'HAVE_CURSES_TYPEAHEAD': 1,
- 'HAVE_CURSES_USE_ENV': 1,
- 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -110,22 +139,32 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_DEV_PTC': 0,
  'HAVE_DEV_PTMX': 1,
  'HAVE_DIRECT_H': 0,
+ 'HAVE_DIRENT_D_TYPE': 1,
  'HAVE_DIRENT_H': 1,
+ 'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
+ 'HAVE_DUP3': 1,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 0,
+ 'HAVE_EPOLL_CREATE1': 0,
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPM1': 1,
+ 'HAVE_FACCESSAT': 1,
  'HAVE_FCHDIR': 1,
  'HAVE_FCHMOD': 1,
+ 'HAVE_FCHMODAT': 1,
  'HAVE_FCHOWN': 1,
+ 'HAVE_FCHOWNAT': 1,
  'HAVE_FCNTL_H': 1,
  'HAVE_FDATASYNC': 1,
+ 'HAVE_FDOPENDIR': 1,
+ 'HAVE_FEXECVE': 1,
  'HAVE_FINITE': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
@@ -133,19 +172,26 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_FPATHCONF': 1,
  'HAVE_FSEEK64': 0,
  'HAVE_FSEEKO': 1,
+ 'HAVE_FSTATAT': 1,
  'HAVE_FSTATVFS': 1,
  'HAVE_FSYNC': 1,
  'HAVE_FTELL64': 0,
  'HAVE_FTELLO': 1,
  'HAVE_FTIME': 1,
  'HAVE_FTRUNCATE': 1,
+ 'HAVE_FUTIMENS': 1,
+ 'HAVE_FUTIMES': 1,
+ 'HAVE_FUTIMESAT': 1,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
+ 'HAVE_GCC_ASM_FOR_X64': 1,
  'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
- 'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
+ 'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 1,
  'HAVE_GETHOSTBYNAME_R': 0,
@@ -163,6 +209,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
+ 'HAVE_GETRANDOM': 1,
+ 'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 0,
  'HAVE_GETRESUID': 0,
  'HAVE_GETSID': 1,
@@ -170,10 +218,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETSPNAM': 0,
  'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
+ 'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
+ 'HAVE_HTOLE64': 1,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 1,
+ 'HAVE_IF_NAMEINDEX': 1,
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
@@ -181,6 +232,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
  'HAVE_IO_H': 1,
+ 'HAVE_IPA_PURE_CONST_BUG': 0,
  'HAVE_KILL': 1,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 0,
@@ -196,45 +248,72 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LIBINTL_H': 1,
  'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
+ 'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
+ 'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_CAN_BCM_H': 0,
+ 'HAVE_LINUX_CAN_H': 0,
+ 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
+ 'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
+ 'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
+ 'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
+ 'HAVE_LOG2': 1,
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LONG_LONG': 1,
  'HAVE_LSTAT': 1,
+ 'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
+ 'HAVE_MBRTOWC': 1,
  'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
+ 'HAVE_MEMRCHR': 1,
+ 'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
+ 'HAVE_MKFIFOAT': 1,
  'HAVE_MKNOD': 1,
+ 'HAVE_MKNODAT': 1,
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 0,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDIR_H': 0,
  'HAVE_NETPACKET_PACKET_H': 0,
+ 'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_OSX105_SDK': 0,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
+ 'HAVE_PIPE2': 1,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
  'HAVE_POLL_H': 1,
+ 'HAVE_POSIX_FADVISE': 1,
+ 'HAVE_POSIX_FALLOCATE': 1,
+ 'HAVE_PREAD': 1,
+ 'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 1,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTH': 0,
  'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
+ 'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
+ 'HAVE_PWRITE': 1,
  'HAVE_READLINK': 1,
+ 'HAVE_READLINKAT': 1,
+ 'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
+ 'HAVE_RENAMEAT': 1,
+ 'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
@@ -244,19 +323,28 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
+ 'HAVE_SCHED_GET_PRIORITY_MAX': 1,
+ 'HAVE_SCHED_H': 1,
+ 'HAVE_SCHED_RR_GET_INTERVAL': 1,
+ 'HAVE_SCHED_SETAFFINITY': 0,
+ 'HAVE_SCHED_SETPARAM': 1,
+ 'HAVE_SCHED_SETSCHEDULER': 1,
  'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
  'HAVE_SEM_UNLINK': 1,
+ 'HAVE_SENDFILE': 0,
  'HAVE_SETEGID': 1,
  'HAVE_SETEUID': 1,
  'HAVE_SETGID': 1,
  'HAVE_SETGROUPS': 1,
+ 'HAVE_SETHOSTNAME': 1,
  'HAVE_SETITIMER': 1,
  'HAVE_SETLOCALE': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
+ 'HAVE_SETPRIORITY': 1,
  'HAVE_SETREGID': 1,
  'HAVE_SETRESGID': 0,
  'HAVE_SETRESUID': 0,
@@ -266,9 +354,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SETVBUF': 1,
  'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
+ 'HAVE_SIGALTSTACK': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
+ 'HAVE_SIGPENDING': 1,
  'HAVE_SIGRELSE': 1,
+ 'HAVE_SIGTIMEDWAIT': 1,
+ 'HAVE_SIGWAIT': 1,
+ 'HAVE_SIGWAITINFO': 1,
  'HAVE_SNPRINTF': 1,
  'HAVE_SOCKADDR_SA_LEN': 0,
  'HAVE_SOCKADDR_STORAGE': 1,
@@ -281,10 +374,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
+ 'HAVE_STD_ATOMIC': 1,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
+ 'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 1,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
@@ -294,14 +389,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
  'HAVE_SYMLINK': 1,
+ 'HAVE_SYMLINKAT': 1,
+ 'HAVE_SYNC': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
  'HAVE_SYS_BSDTTY_H': 0,
+ 'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
+ 'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 0,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
+ 'HAVE_SYS_IOCTL_H': 1,
+ 'HAVE_SYS_KERN_CONTROL_H': 0,
  'HAVE_SYS_LOADAVG_H': 0,
  'HAVE_SYS_LOCK_H': 1,
  'HAVE_SYS_MKDEV_H': 0,
@@ -312,24 +413,27 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
+ 'HAVE_SYS_SENDFILE_H': 0,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
- 'HAVE_SYS_SYSMACROS_H': 1,
+ 'HAVE_SYS_SYSCALL_H': 0,
+ 'HAVE_SYS_SYS_DOMAIN_H': 0,
  'HAVE_SYS_TERMIO_H': 1,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
  'HAVE_SYS_TYPES_H': 1,
+ 'HAVE_SYS_UIO_H': 1,
  'HAVE_SYS_UN_H': 1,
  'HAVE_SYS_UTSNAME_H': 1,
  'HAVE_SYS_WAIT_H': 1,
+ 'HAVE_SYS_XATTR_H': 1,
  'HAVE_TCGETPGRP': 1,
  'HAVE_TCSETPGRP': 1,
  'HAVE_TEMPNAM': 1,
  'HAVE_TERMIOS_H': 1,
  'HAVE_TERM_H': 1,
  'HAVE_TGAMMA': 1,
- 'HAVE_THREAD_H': 0,
  'HAVE_TIMEGM': 1,
  'HAVE_TIMES': 1,
  'HAVE_TMPFILE': 1,
@@ -344,78 +448,102 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_UINTPTR_T': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
+ 'HAVE_UNLINKAT': 1,
  'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 1,
  'HAVE_UTIL_H': 0,
+ 'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
+ 'HAVE_WAITID': 0,
  'HAVE_WAITPID': 1,
  'HAVE_WCHAR_H': 1,
  'HAVE_WCSCOLL': 1,
+ 'HAVE_WCSFTIME': 1,
+ 'HAVE_WCSXFRM': 1,
+ 'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
+ 'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-cygwin',
- 'HURD_C_THREADS': 0,
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python2.7 /usr/include/python2.7',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.5m '
+                   '/usr/include/python3.5m',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python2.7',
+ 'INCLUDEPY': '/usr/include/python3.5m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython2.7.dll.a',
+ 'INSTSONAME': 'libpython3.5m.dll.a',
+ 'IO_H': 'Modules/_io/_iomodule.h',
+ 'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared -Wl,--enable-auto-image-base',
- 'LDFLAGS': '-L.',
+ 'LDFLAGS': '',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython2.7.dll.a',
+ 'LDLIBRARY': 'libpython3.5m.dll.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base -L.',
+ 'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
+ 'LDVERSION': '3.5m',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python2.7',
+ 'LIBDEST': '/usr/lib/python3.5',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBP': '/usr/lib/python2.7',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python2.7/config',
- 'LIBRARY': 'libpython2.7.a',
+ 'LIBPL': '/usr/lib/python3.5/config-3.5m',
+ 'LIBRARY': 'libpython3.5m.a',
  'LIBRARY_OBJS': '\\',
+ 'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lintl -ldl',
- 'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
+ 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '',
+ 'LIPO_32BIT_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
  'LN': 'ln -s',
  'LOCALMODLIBS': '',
+ 'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'cygwin',
  'MACHDEPPATH': ':plat-cygwin',
  'MACHDEPS': 'plat-cygwin',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python2.7',
- 'MACH_C_THREADS': 0,
+ 'MACHDESTLIB': '/usr/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18/Modules/makesetup',
+ 'MAKESETUP': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/zipimport.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODNAMES': '_thread _signal posix errno pwd _sre _codecs _weakref _functools '
+             '_operator _collections itertools atexit _stat time _locale _io '
+             'zipimport faulthandler _tracemalloc _symtable xxsubtype',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
+            'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
+            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
+            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
+            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
+            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
+            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 1,
+ 'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OLDPATH': ':lib-old',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -425,7 +553,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
  'PGEN': 'Parser/pgen.exe',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
@@ -434,35 +562,55 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-cygwin',
- 'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
- 'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing test_subprocess',
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
+                 'test_multiprocessing_fork test_multiprocessing_forkserver '
+                 'test_multiprocessing_main_handling '
+                 'test_multiprocessing_spawn test_subprocess',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
  'PURIFY': '',
+ 'PY3LIBRARY': '',
  'PYLONG_BITS_IN_DIGIT': 0,
  'PYTHON': 'python.exe',
  'PYTHONFRAMEWORK': '',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-cygwin:lib-tk:lib-old',
+ 'PYTHONPATH': ':plat-cygwin',
  'PYTHON_FOR_BUILD': './python.exe -E',
- 'PYTHON_FOR_REGEN': 'python2.7',
+ 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-4.x86_64/build=/usr/src/debug/python2-2.7.18-4 -fdebug-prefix-map=/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18=/usr/src/debug/python2-2.7.18-4 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18/Include  -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
+              '-Wstrict-prototypes -ggdb -O2 -pipe -Wall '
+              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+              '-fstack-protector-strong --param=ssp-buffer-size=4 '
+              '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
+              '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1',
+ 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
+                   '-Wall -Wstrict-prototypes -ggdb -O2 -pipe -Wall '
+                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                   '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
+                   '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1 '
+                   '-Werror=declaration-after-statement -IObjects -IInclude '
+                   '-IPython -I. '
+                   '-I/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Include  '
+                   '-DPy_BUILD_CORE',
+ 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
+                '-I/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_UNICODE_TYPE': 'wchar_t',
+ 'PY_LDFLAGS': '',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
- 'Py_UNICODE_SIZE': 2,
- 'Py_USING_UNICODE': 1,
- 'QUICKTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\',
+ 'Py_HASH_ALGORITHM': 0,
+ 'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
+ 'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
  'RUNSHARED': '',
@@ -471,7 +619,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lintl -ldl',
- 'SHLIB_EXT': '".dll"',
+ 'SHLIB_SUFFIX': '.dll',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -492,37 +640,38 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 2,
  'SIZEOF__BOOL': 1,
- 'SO': '.dll',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io',
- 'SRC_GDB_HOOKS': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18/Tools/gdb/libpython.py',
+ 'SOABI': 'cpython-35m-x86_64-cygwin',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
+ 'SRC_GDB_HOOKS': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
- 'STRINGLIB_HEADERS': '\\',
+ 'STRIPFLAG': '-s',
  'SUBDIRS': '',
- 'SUBDIRSTOO': 'Include Lib Misc Demo',
+ 'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
- 'TESTOPTS': '-l',
+ 'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPROG': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18/Lib/test/regrtest.py',
- 'TESTPYTHON': './python.exe -Wd -3 -E -tt',
+ 'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
+ 'TESTRUNNER': './python.exe '
+               '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Tools/scripts/run_tests.py',
+ 'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
+ 'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
- 'TKPATH': ':lib-tk',
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_OBJS': 'Objects/unicodeobject.o Objects/unicodectype.o',
+ 'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
- 'USE_TOOLBOX_OBJECT_GLUE': 0,
+ 'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 0,
- 'VERSION': '2.7',
- 'VPATH': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18',
+ 'VERSION': '3.5',
+ 'VPATH': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6',
  'WANT_SIGFPE_HANDLER': 0,
- 'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
  'WITH_DYLD': 0,
@@ -534,11 +683,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/build',
- 'abs_srcdir': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18',
- 'build': 'x86_64-pc-cygwin',
+ 'abs_builddir': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/build',
+ 'abs_srcdir': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
- 'host': 'x86_64-pc-cygwin',
  'prefix': '/usr',
- 'srcdir': '/pub/devel/python/python27/python2-2.7.18-4.x86_64/src/Python-2.7.18'}
+ 'srcdir': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6'}
