@@ -1,11 +1,7 @@
-#!/usr/bin/env python2
-from __future__ import print_function
-
 import distutils.version
 import glob
 import os
 import os.path
-import shutil
 import sys
 import tempfile
 
@@ -14,6 +10,7 @@ __all__ = ["version", "bootstrap"]
 
 _WHEEL_DIR = "/usr/share/python-wheels/"
 
+
 def _get_most_recent_wheel_version(pkg):
     prefix = os.path.join(_WHEEL_DIR, "{}-".format(pkg))
     suffix = "-py2.py3-none-any.whl"
@@ -26,6 +23,19 @@ _SETUPTOOLS_VERSION = _get_most_recent_wheel_version("setuptools")
 
 _PIP_VERSION = _get_most_recent_wheel_version("pip")
 
+# pip currently requires ssl support, so we try to provide a nicer
+# error message when that is missing (http://bugs.python.org/issue19744)
+_MISSING_SSL_MESSAGE = ("pip {} requires SSL/TLS".format(_PIP_VERSION))
+try:
+    import ssl
+except ImportError:
+    ssl = None
+    def _require_ssl_for_pip():
+        raise RuntimeError(_MISSING_SSL_MESSAGE)
+else:
+    def _require_ssl_for_pip():
+        pass
+
 _PROJECTS = [
     ("setuptools", _SETUPTOOLS_VERSION),
     ("pip", _PIP_VERSION),
@@ -38,8 +48,13 @@ def _run_pip(args, additional_paths=None):
         sys.path = additional_paths + sys.path
 
     # Install the bundled software
-    import pip._internal
-    return pip._internal.main(args)
+    try:
+        # pip 10
+        from pip._internal import main
+    except ImportError:
+        # pip 9
+        from pip import main
+    main(args)
 
 
 def version():
@@ -48,7 +63,6 @@ def version():
     """
     return _PIP_VERSION
 
-
 def _disable_pip_configuration_settings():
     # We deliberately ignore all pip environment variables
     # when invoking pip
@@ -61,33 +75,19 @@ def _disable_pip_configuration_settings():
     os.environ['PIP_CONFIG_FILE'] = os.devnull
 
 
-def bootstrap(root=None, upgrade=False, user=False,
-              altinstall=False, default_pip=True,
+def bootstrap(*, root=None, upgrade=False, user=False,
+              altinstall=False, default_pip=False,
               verbosity=0):
     """
     Bootstrap pip into the current Python installation (or the given root
     directory).
 
-    Note that calling this function will alter both sys.path and os.environ.
-    """
-    # Discard the return value
-    _bootstrap(root=root, upgrade=upgrade, user=user,
-               altinstall=altinstall, default_pip=default_pip,
-               verbosity=verbosity)
-
-
-def _bootstrap(root=None, upgrade=False, user=False,
-               altinstall=False, default_pip=True,
-               verbosity=0):
-    """
-    Bootstrap pip into the current Python installation (or the given root
-    directory). Returns pip command status code.
-
     Note that calling this function will alter both sys.path and os.environ.
     """
     if altinstall and default_pip:
         raise ValueError("Cannot use altinstall and default_pip together")
 
+    _require_ssl_for_pip()
     _disable_pip_configuration_settings()
 
     # By default, installing pip and setuptools installs all of the
@@ -103,8 +103,7 @@ def _bootstrap(root=None, upgrade=False, user=False,
         # omit pip and easy_install
         os.environ["ENSUREPIP_OPTIONS"] = "install"
 
-    tmpdir = tempfile.mkdtemp()
-    try:
+    with tempfile.TemporaryDirectory() as tmpdir:
         # Put our bundled wheels into a temporary directory and construct the
         # additional paths that need added to sys.path
         additional_paths = []
@@ -127,11 +126,9 @@ def _bootstrap(root=None, upgrade=False, user=False,
         if verbosity:
             args += ["-" + "v" * verbosity]
 
-        return _run_pip(args + [p[0] for p in _PROJECTS], additional_paths)
-    finally:
-        shutil.rmtree(tmpdir, ignore_errors=True)
+        _run_pip(args + [p[0] for p in _PROJECTS], additional_paths)
 
-def _uninstall_helper(verbosity=0):
+def _uninstall_helper(*, verbosity=0):
     """Helper to support a clean default uninstall process on Windows
 
     Note that calling this function may alter os.environ.
@@ -149,6 +146,7 @@ def _uninstall_helper(verbosity=0):
         print(msg.format(pip.__version__, _PIP_VERSION), file=sys.stderr)
         return
 
+    _require_ssl_for_pip()
     _disable_pip_configuration_settings()
 
     # Construct the arguments to be passed to the pip command
@@ -156,10 +154,15 @@ def _uninstall_helper(verbosity=0):
     if verbosity:
         args += ["-" + "v" * verbosity]
 
-    return _run_pip(args + [p[0] for p in reversed(_PROJECTS)])
+    _run_pip(args + [p[0] for p in reversed(_PROJECTS)])
 
 
 def _main(argv=None):
+    if ssl is None:
+        print("Ignoring ensurepip failure: {}".format(_MISSING_SSL_MESSAGE),
+              file=sys.stderr)
+        return
+
     import argparse
     parser = argparse.ArgumentParser(prog="python -m ensurepip")
     parser.add_argument(
@@ -197,27 +200,20 @@ def _main(argv=None):
         "--altinstall",
         action="store_true",
         default=False,
-        help=("Make an alternate install, installing only the X.Y versioned "
-              "scripts (Default: pipX, pipX.Y, easy_install-X.Y)."),
+        help=("Make an alternate install, installing only the X.Y versioned"
+              "scripts (Default: pipX, pipX.Y, easy_install-X.Y)"),
     )
     parser.add_argument(
         "--default-pip",
         action="store_true",
-        default=True,
-        dest="default_pip",
-        help=argparse.SUPPRESS,
-    )
-    parser.add_argument(
-        "--no-default-pip",
-        action="store_false",
-        dest="default_pip",
-        help=("Make a non default install, installing only the X and X.Y "
-              "versioned scripts."),
+        default=False,
+        help=("Make a default pip install, installing the unqualified pip "
+              "and easy_install in addition to the versioned scripts"),
     )
 
     args = parser.parse_args(argv)
 
-    return _bootstrap(
+    bootstrap(
         root=args.root,
         upgrade=args.upgrade,
         user=args.user,
